/// <reference types="bn.js" />
import { ConfirmOptions, Connection, PublicKey, Transaction, TransactionInstruction, Signer } from '@solana/web3.js';
import { BN, Idl, Program } from '@project-serum/anchor';
import { Token } from '@solana/spl-token';
export declare const STATE_SEED = "fstate1";
export declare const ACCOUNT_SEED = "faccv1";
export declare const CPI_SEED = "FABRIC";
export declare class Protocol {
    connection: Connection;
    programId: PublicKey;
    adminPubkey: PublicKey;
    assetsListPubkey: PublicKey;
    statePubkey: PublicKey;
    cpiAuthPubkey: PublicKey;
    wallet: IWallet;
    idl: Idl;
    faucetIdl: Idl;
    pythIdl: Idl;
    program: Program;
    faucetProgram: Program;
    state: any;
    assetsList: any;
    private constructor();
    static initialise(connection: Connection, wallet: IWallet, programId: PublicKey, faucetProgramId?: PublicKey, opts?: ConfirmOptions): Promise<Protocol>;
    initialiseContract(epochDurationInSlots: number, rewardTokenAAccount: PublicKey, rewardWithdrawlDelay?: number, rewardTokenAPerEpoch?: number): Promise<string>;
    initialiseAssetsList(collateralMintPubkey: PublicKey, collateralFeedPubkey: PublicKey, collateralReserveAccountPubkey: PublicKey, collateralLiquidationFundAccountPubkey: PublicKey): Promise<[string, Token, PublicKey]>;
    setAssetsListAccount(assetListPubkey: PublicKey): Promise<string>;
    depositCollateral(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey, signer?: Signer): Promise<string>;
    depositCollateralIx(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey): Promise<TransactionInstruction>;
    mint(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey, signer?: Signer): Promise<string>;
    mintIx(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey): Promise<TransactionInstruction>;
    burn(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey, signer?: Signer): Promise<string>;
    burnIx(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey): Promise<TransactionInstruction>;
    withdrawCollateral(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey, signer?: Signer): Promise<string>;
    withdrawCollateralIx(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey): Promise<TransactionInstruction>;
    swap(amount: BN, owner: PublicKey, tokenAMint: PublicKey, tokenBMint: PublicKey, tokenAReceiver: PublicKey, tokenBReceiver: PublicKey, userAccount: PublicKey, signer?: Signer): Promise<string>;
    swapIx(amount: BN, owner: PublicKey, tokenAMint: PublicKey, tokenBMint: PublicKey, tokenAReceiver: PublicKey, tokenBReceiver: PublicKey, userAccount: PublicKey): Promise<TransactionInstruction>;
    claimRewards(userAccount: PublicKey): Promise<string>;
    claimRewardsIx(userAccount: PublicKey): Promise<TransactionInstruction>;
    withdrawRewards(userAccount: PublicKey, owner: PublicKey, rewardTokenAReceiver: PublicKey): Promise<string>;
    updatePrices(): Promise<string>;
    updatePricesIx(): Promise<TransactionInstruction>;
    getStateAccount(): Promise<[PublicKey, number]>;
    getState(): Promise<IState>;
    getAssetList(): Promise<IAssetList>;
    createUserAccount(owner: PublicKey): Promise<PublicKey>;
    createUserAccountIx(owner: PublicKey): Promise<TransactionInstruction>;
    getUserAccount(owner: PublicKey): Promise<[PublicKey, number]>;
    getUser(userAccount: PublicKey): Promise<IUser>;
    checkIfUserAccountExists(owner: PublicKey): Promise<boolean>;
    getCpiAuthAccount(): Promise<[PublicKey, number]>;
    mintTokens(amount: number, decimals: number, toAddress: PublicKey, token: Token, authority?: PublicKey, signer?: Signer): Promise<void>;
    createTokenAccount(token: Token, owner: PublicKey): Promise<PublicKey>;
    getAccountBalanceForMint(tokenAccount: PublicKey): Promise<any>;
    getAccountBalance(tokenAccount: PublicKey): Promise<number>;
    getTokenAccountInfo(token: Token, tokenAccount: PublicKey): Promise<import("@solana/spl-token").AccountInfo>;
    getfUsdTokenMint(): Promise<PublicKey>;
    createToken(decimals: number, authority?: PublicKey): Promise<Token>;
    getUserCollateralRatio(userAccount: PublicKey): Promise<number>;
    getUserDebtUsd(userAccount: PublicKey): Promise<number>;
    getUserCollateralUsd(userAccount: PublicKey): Promise<number>;
    getMaximumPossibleUserDebtUsd(userAccount: PublicKey): Promise<number>;
    getGlobalDebtUsd(): Promise<number>;
    getSyntheticSupplyAndMarketCap(mint: PublicKey): Promise<{
        supply: number;
        scaledPrice: number;
        marketCap: number;
    }>;
    getCollateralTvlAndCRatio(mint: PublicKey): Promise<{
        collateralTvl: number;
        collateralRatio: number;
    }>;
    haltProtocol(): Promise<string>;
    unhaltProtocol(): Promise<string>;
    updateEpochDuration(durationInSlots: number): Promise<string>;
    updateEpochRewardTokenAAmount(newRewardAmountScaled: BN): Promise<string>;
    updateRewardTokenAAccount(rewardTokenAAccount: PublicKey): Promise<string>;
    airdropFab(owner: PublicKey): Promise<string>;
    airdropFabDirectly(owner: PublicKey, fabAccount: PublicKey, amount?: number): Promise<string>;
    getFabAirdropMintProgramAddress(): Promise<[PublicKey, number]>;
}
export interface IWallet {
    signTransaction(tx: Transaction): Promise<Transaction>;
    signAllTransactions(txs: Transaction[]): Promise<Transaction[]>;
    publicKey: PublicKey;
}
export interface IUser {
    owner: PublicKey;
    userDebtShares: BN;
    liquidationDeadline: BN;
    numberOfCollaterals: number;
    bump: number;
    userStakingData: IUserStakingData;
    userCollaterals: Array<IUserCollateral>;
}
export interface IUserCollateral {
    amount: BN;
    collateralMintAddress: PublicKey;
    index: number;
}
export interface IUserStakingData {
    firstUpdate: BN;
    claimableRewards: IDecimal;
    lastEpochDebtShares: BN;
    currentEpochDebtShares: BN;
    nextEpochDebtShares: BN;
    lastUpdate: BN;
}
export interface IAsset {
    priceFeedAddress: PublicKey;
    price: IDecimal;
    lastUpdate: number;
    status: number;
    oracleType: number;
}
export interface IAssetList {
    numberOfAssets: number;
    numberOfCollaterals: number;
    numberOfSynthetics: number;
    assets: Array<IAsset>;
    collaterals: Array<ICollateral>;
    synthetics: Array<ISynthetic>;
}
export interface IState {
    adminPubkey: PublicKey;
    cpiAuthPubkey: PublicKey;
    nonce: number;
    bump: number;
    isHalted: boolean;
    debtShares: BN;
    liquidationBuffer: BN;
    delayBuffer: BN;
    rewardWithdrawlBuffer: BN;
    assetsList: PublicKey;
    protocolSwapFee: IDecimal;
    globalStakingData: IGlobalStakingData;
}
export interface ICollateral {
    assetIndex: number;
    collateralMintAddress: PublicKey;
    reserveAddress: PublicKey;
    liquidationFundAddress: PublicKey;
    reserveBalance: IDecimal;
    collateralRatio: IDecimal;
    maximumCollateral: IDecimal;
}
export interface ISynthetic {
    assetIndex: number;
    assetAddress: PublicKey;
    supply: IDecimal;
    maximumSupply: IDecimal;
}
export interface IDecimal {
    val: BN;
    scale: number;
}
export interface IGlobalStakingData {
    epochDurationSlots: BN;
    rewardTokenAAccount: PublicKey;
    rewardTokenAPerEpoch: IDecimal;
    nextEpochData: IStakingEpochData;
    currentEpochData: IStakingEpochData;
    previousEpochData: IStakingEpochData;
}
export interface IStakingEpochData {
    globalDebtShares: BN;
    startSlot: BN;
    rewardTokenAForEpoch: IDecimal;
}
